@@ -1,4 +1,4 @@
-from nonebot.params import CommandArg,ArgPlainText,RegexGroup,Arg
+from nonebot.params import CommandArg,ArgPlainText,RegexGroup,Arg,Command,RawCommand
 from nonebot.adapters.onebot.v11 import NoticeEvent,Bot,MessageEvent,Message,MessageSegment,GroupMessageEvent
 from nonebot.matcher import Matcher
 from nonebot.typing import T_State
@@ -10,13 +10,15 @@ from .command import *
 from .l4d2_image.steam import url_to_byte
 from nonebot.plugin import PluginMetadata
 from .l4d2_data import sq_L4D2
-from .l4d2_anne.server import updata_anne_server,get_anne_ip
+from .l4d2_anne.server import get_anne_ip
 from nonebot import get_driver
-from .l4d2_image.vtf import img_to_vtf
+from .l4d2_image.vtfs import img_to_vtf
+from .l4d2_queries.ohter import load_josn
+from .l4d2_queries.qqgroup import write_json
 driver = get_driver()
 
 
-__version__ = "0.2.2"
+__version__ = "0.2.3"
 __plugin_meta__ = PluginMetadata(
     name="求生之路小助手",
     description='群内对有关求生之路的查询和操作',
@@ -116,9 +118,11 @@ async def _(matched: Tuple[int,str, str] = RegexGroup(),):
 async def _(event:MessageEvent,args:Message = CommandArg()):
     name = args.extract_plain_text()
     name = name.strip()
-    usr_id = event.user_id
     at = await get_message_at(event.json())
-    usr_id = at_to_usrid(usr_id,at)
+    if at:
+        usr_id = at_to_usrid(at)
+    else:
+        usr_id = event.user_id
     # 没有参数则从db里找数据
     msg = await search_anne(name,usr_id)
     if type(msg)==str:
@@ -238,16 +242,18 @@ async def _(matcher: Matcher,bot:Bot,event:GroupMessageEvent,state:T_State):
     else:
         await up_workshop.finish('已取消上传')
     
-    
 
 
-# @updata.handle()
-# async def _():
-#     msg = await updata_anne_server()
-#     if msg:
-#         n = len(msg)
-#         await updata.finish(f'更新成功，目前有{n}个ip')
-#     await updata.finish('获取失败了')
+@updata.handle()
+async def _(args:Message = CommandArg()):
+    msg = args.extract_plain_text()
+    if not msg:
+        load_josn()
+        reload_ip()
+        await updata.finish('已更新缓存数据')
+    else:
+        message = await write_json(msg)
+        await updata.finish(message)
 
 @get_anne.handle()
 async def _(args:Message = CommandArg()):
@@ -284,8 +290,23 @@ async def _(event:MessageEvent):
             ip = ANNE_IP[key]
             host,port = split_maohao(ip)
             ip_list.append((key,group,host,port))
-    msg = await get_tan_jian(ip_list)
+    msg = await get_tan_jian(ip_list,1)
     await tan_jian.finish(msg)
+
+@get_ip.handle()
+async def _(command: str = RawCommand(),args:Message = CommandArg()):
+    logger.info(command)
+    msg:str = args.extract_plain_text()
+    logger.info(msg)
+    message = await json_server_to_tag_dict(command,msg)
+    if len(message) == 0:
+        # 关键词不匹配，忽略
+        return
+    ip = str(message['host']) + ':' + str(message['port'])
+    logger.info(ip)
+    msg= await get_anne_server_ip(ip)
+    await get_ip.finish(msg)
+
             
 @vtf_make.handle()
 async def _(matcher:Matcher,state:T_State,args:Message = CommandArg()):
@@ -306,9 +327,9 @@ async def _(bot:Bot,event:MessageEvent,state:T_State,tag = Arg("image")):
     tag = state['way']
     pic_bytes = await url_to_byte(pic_url)
     img_io = await img_to_vtf(pic_bytes,tag)
-    img_bytes = img_io.getvalue()
+    img_bytes = img_io.getbuffer()
     usr_id = event.user_id
-    file_name:str = usr_id + '的喷漆.vtf'
+    file_name:str = str(usr_id) + '.vtf'
     await upload_file(bot, event, img_bytes, file_name)
 
 
@@ -324,7 +345,22 @@ async def _(event:MessageEvent):
             ip = ANNE_IP[key]
             host,port = split_maohao(ip)
             ip_list.append((key,group,host,port))
-    msg = await get_tan_jian(ip_list)
+    msg = await get_tan_jian(ip_list,2)
+    await tan_jian.finish(msg)
+
+@open_prison.handle()
+async def _(event:MessageEvent):
+    group = event.user_id
+    await tan_jian.send('正在寻找空房...')
+    ip_list = []
+    keys = ANNE_IP.keys()
+    for key in keys:
+        key:str
+        if key.startswith('云'):
+            ip = ANNE_IP[key]
+            host,port = split_maohao(ip)
+            ip_list.append((key,group,host,port))
+    msg = await get_tan_jian(ip_list,3)
     await tan_jian.finish(msg)
 
 @driver.on_shutdown
