@@ -13,7 +13,7 @@ except:
 file_format = (".vpk",".zip",".7z")
 Master = SUPERUSER | GROUP_ADMIN | GROUP_OWNER 
 # file 填写求生服务器所在路径
-FONT_ORIGIN_PATH = Path()/ 'data/L4D2/font.ttf'
+FONT_ORIGIN_PATH = Path(__file__).parent / 'data/L4D2/font.ttf'
 try:
     l4_file: str = nonebot.get_driver().config.l4_file
 except:
@@ -32,7 +32,7 @@ except:
 try:
     l4_font: str = nonebot.get_driver().config.l4_font
 except:
-    l4_font: str = str(FONT_ORIGIN_PATH)   
+    l4_font: str = str(FONT_ORIGIN_PATH)
      
 try:
     l4_host: str = nonebot.get_driver().config.l4_host
@@ -48,7 +48,12 @@ try:
     l4_rcon: str = nonebot.get_driver().config.l4_rcon
 except:
     l4_rcon: str = '114514'
-
+try:
+    l4_proxies: str = {
+            'http://':nonebot.get_driver().config.l4_proxies
+        }
+except:
+    l4_proxies = ''
 # 文件路径
 vpk_path = "left4dead2/addons"
 cfg_server = Path(l4_file,'left4dead2/cfg/server.cfg')
@@ -56,10 +61,6 @@ map_path = Path(l4_file,vpk_path)
 '''
 地图路径
 '''
-players_data:dict[str(dict)] = json.load(open(Path(__file__).parent.joinpath('data/L4D2/player.json'), "r", encoding="utf8"))
-"""绑定信息dict"""
-
-
 
 PLAYERSDATA = Path() / "data/L4D2/image/players"
 """用户数据路径"""
@@ -90,4 +91,8 @@ L4d2_BOOLEAN = ['use']
 tables_columns = {
     table_data[0]:L4d2_players_tag,
     table_data[1]:L4d2_server_tag
-}
\ No newline at end of file
+}
+
+# 求生anne服务器
+anne_url = "https://server.trygek.com/"
+
